# ahttptemplate

aiohttp restful api template

## environment variables

```ini
API_TYPE=JSON
LOG_LEVEL=10
```

## logging levels

-   **CRITICAL:** 50
-   **ERROR:** 40
-   **WARNING:** 30
-   **INFO:** 20
-   **DEBUG:** 10
